summaryrefslogtreecommitdiff
path: root/deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js')
-rw-r--r--deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js b/deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js
index 4a571d5dd0..6aa3094179 100644
--- a/deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js
+++ b/deps/v8/tools/clusterfuzz/js_fuzzer/exceptions.js
@@ -97,14 +97,14 @@ const DISALLOWED_FLAGS = [
// stabilized yet and would cause too much noise when enabled.
/^--experimental-.*/,
// Disallowed due to noise. We explicitly add --es-staging to job
// definitions, and all of these features are staged before launch.
/^--harmony-.*/,
// Disallowed because they are passed explicitly on the command line.
'--allow-natives-syntax',
'--debug-code',
- '--es-staging',
+ '--harmony',
'--wasm-staging',
'--expose-gc',
'--expose_gc',
@@ -97,14 +97,14 @@ const DISALLOWED_FLAGS = [
// stabilized yet and would cause too much noise when enabled.
/^--experimental-.*/,
- // Disallowed due to noise. We explicitly add --es-staging to job
+ // Disallowed due to noise. We explicitly add --harmony to job
// definitions, and all of these features are staged before launch.
/^--harmony-.*/,